Get schwifty with IBANs and BICs
================================

Release v\ |release| (:ref:`What's new <changelog>`)

.. include:: ../../README.rst
   :start-after: teaser-begin
   :end-before: teaser-end

.. include:: ../../README.rst
   :start-after: installation-begin
   :end-before: installation-end

.. note::

   Starting from version 2021.01.0 schwifty only supports Python 3.6+


API documentation
-----------------
.. toctree::
   :maxdepth: 2

   examples
   api
   troubleshooting

.. toctree::
   :maxdepth: 1

   changelog
